﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

// Used so I can use Floor
using System;

public class Link : MonoBehaviour {
	
	// Speed Link moves
	public float speed;

	// Used to move Link
	private Rigidbody2D rb;

	// Used to access the function IsValidSpace in Gameboard.cs
	Gameboard gameBoard;

	// Get reference to the SoundManager for functions
	// SoundManager soundManager;

	// Used to change Link animations
	Animator animator;

	// Makes sure components have been created when the 
	// game starts
	void Awake(){
		// Get Links Rigidbody
		rb = GetComponent<Rigidbody2D> ();

		// Setup Gameboard so I can access functions
		gameBoard = FindObjectOfType(typeof(Gameboard)) as Gameboard;

		// Get SoundManager reference
		// soundManager = GameObject.Find ("SoundManager").GetComponent<SoundManager> ();

		// Get Animator reference
		animator = GetComponent<Animator>();
	}

	// Used to flip the animations
	bool facingRight = false;
	bool facingLeft = false;

	void FixedUpdate(){

		// Get keyboard input
		float horzMove = Input.GetAxisRaw ("Horizontal");
		float vertMove = Input.GetAxisRaw ("Vertical");

		if (gameBoard.IsValidSpace ((float)transform.position.x + horzMove,
			(float)transform.position.y + vertMove, horzMove, vertMove)) {

			rb.velocity = new Vector2 (horzMove * speed, vertMove * speed);

		} else {

			rb.velocity = new Vector2 (0,0);

		}

		if (Input.GetKey ("s")) {

			animator.Play ("WalkDown");

		}

		if (Input.GetKey ("w")) {

			animator.Play ("WalkUp");

		}

		if (Input.GetKey ("d")) {

			animator.Play ("WalkRight");

			// Flips the animation to the right
			if (facingLeft) {
				facingRight = true;
				facingLeft = false;
				animator.transform.Rotate (0, 180, 0);
			} else if (!facingLeft) {
				facingRight = true;
			}

		}

		if (Input.GetKey ("a")) {

			animator.Play ("WalkRight");

			// Flips the animation to the left
			if (facingRight) {
				facingLeft = true;
				facingRight = false;
				animator.transform.Rotate (0, 180, 0);
			} else if (!facingRight) {
				facingLeft = true;
			}

		}

		// Switches back to the Idle position if a key is released
		if (Input.GetKeyUp ("s")) {

			animator.Play ("Idle");

			// When stopped Link will move back into a valid position
			float centerX = (float)Math.Round(Convert.ToDouble(transform.position.x));
			float centerY = (float)Math.Round(Convert.ToDouble(transform.position.y));

			transform.position = new Vector2(centerX, centerY);

		}

	}

	void Start () 
	{
		// set the desired aspect ratio (the values in this example are
		// hard-coded for 16:9, but you could make them into public
		// variables instead so you can set them at design time)
		float targetaspect = 16.0f / 9.0f;

		// determine the game window's current aspect ratio
		float windowaspect = (float)Screen.width / (float)Screen.height;

		// current viewport height should be scaled by this amount
		float scaleheight = windowaspect / targetaspect;

		// obtain camera component so we can modify its viewport
		Camera camera = GetComponent<Camera>();

		// if scaled height is less than current height, add letterbox
		if (scaleheight < 1.0f)
		{  
			Rect rect = camera.rect;

			rect.width = 1.0f;
			rect.height = scaleheight;
			rect.x = 0;
			rect.y = (1.0f - scaleheight) / 2.0f;

			camera.rect = rect;
		}
		else // add pillarbox
		{
			float scalewidth = 1.0f / scaleheight;

			Rect rect = camera.rect;

			rect.width = scalewidth;
			rect.height = 1.0f;
			rect.x = (1.0f - scalewidth) / 2.0f;
			rect.y = 0;

			camera.rect = rect;
		}
	}

}
