﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Villain : MonoBehaviour {

	public float speed = 2f;
	Vector2 direction = Vector2.right;
	bool chasing = false;
	private Animator animator;
	public GameObject linkGO;
	Rigidbody2D rb;

	int[,] villainNodes = new int[,] {{1,1}, {10, 2}, {5, 9}, {7, 15},
		{13, 15}, {15,10}, {15, 3}, {22, 3}, {24, 5}, {21, 9}, {23, 13}};

	public int currentNode = 1;

	public int targetNode = 2;

	GameObject[] villainNodeGOs;
	GameObject linksClosestNodeGO;

	// NEW STUFF
	// Used to pause Villain motion on hit
	public bool stunned = false;

	// END OF NEW STUFF


	void Awake(){
		linkGO = GameObject.Find ("Link");
		rb = GetComponent<Rigidbody2D> ();
		animator = GetComponent<Animator> ();
		villainNodeGOs = GameObject.FindGameObjectsWithTag ("VillainNode");
	}

	void FixedUpdate(){
		// rb.velocity = direction * speed;



			if (Input.GetKeyUp ("f")) {
				if (targetNode < 10) {
					targetNode = targetNode + 1;
					GoForwardToNode ();

					linksClosestNodeGO = LinksClosestNode ();

					Debug.Log ("Links closest node " +
					GetIndexForLinksClosestNode (linksClosestNodeGO));
				}
			}

			if (Input.GetKeyUp ("b")) {
				if (targetNode > 0) {
					targetNode = targetNode - 1;
					GoForwardToNode ();
				}
			}

	}

	void GoForwardToNode(){
		if(!AtTargetNode()){
			Vector2 targetPosition = new Vector2 (villainNodes [targetNode, 0] - transform.position.x,
				villainNodes [targetNode, 1] - transform.position.y);
			direction = targetPosition;
		}
	}

	// NEW STUFF

	// Holds the direction previous to stun
	Vector2 prevDir;

	void Update(){

		// If not stunned allow movement
		if (!stunned) {

			rb.velocity = direction;
			prevDir = direction;

		} else {

			StartCoroutine (UnstunVillain ());

		}

	}

	// Unstuns Villain after 3 seconds
	IEnumerator UnstunVillain(){

		// Stop movement of Villain
		rb.velocity = Vector2.zero;

		// Wait 3 seconds
		yield return new WaitForSeconds(3.0f);

		// Set movement back to normal
		rb.velocity = prevDir;

		// Set as not stunned
		this.stunned = false;

	}

	// END OF NEW STUFF

	GameObject LinksClosestNode(){
		GameObject closestNodeGO = null;
		foreach(GameObject nodeGO in villainNodeGOs){
			if(closestNodeGO == null){
				closestNodeGO = nodeGO;
			}

			if(Vector3.Distance(linkGO.transform.position,
				nodeGO.transform.position) <= Vector3.Distance(linkGO.transform.position,
					closestNodeGO.transform.position )){
				closestNodeGO = nodeGO;
			}
		}

		return closestNodeGO;
	}

	int GetIndexForLinksClosestNode(GameObject linksNodeGO){
		int nodeIndex = 0;

		for(int i = 0; i <= villainNodes.GetUpperBound(0); i++){
			if(linksNodeGO.transform.position.x == villainNodes[i,0] && 
				linksNodeGO.transform.position.y == villainNodes[i,1]){
				nodeIndex = i;
			}
		}
		return nodeIndex;
	}

	bool AtTargetNode(){
		if(transform.position.x == villainNodes[targetNode, 0] && 
			transform.position.y == villainNodes[targetNode, 1]){
			return true;
		} else { 
			return false;
		}
	}

	void OnTriggerEnter2D(Collider2D col){
		if(!chasing){
			transform.localScale = new Vector2 (-1 * transform.localScale.x,
				transform.localScale.y);

			direction = new Vector2 (-1 * direction.x, direction.y);
		} else {

		}

		if(col.tag == "VillainNode"){
			if(col.transform.position.x == villainNodes[targetNode, 0] && 
				col.transform.position.y == villainNodes[targetNode, 1]){
				direction = Vector3.zero;
			}
		}
	}

}
